SWDEV-327563 - Enable fixed tests linux and windows v3 (#2943)
Change-Id: Ia5c47821268d7f31b70c473ef2a4785b6735a2f1
Este commit está contenido en:
cometido por
GitHub
padre
ece11e4ed3
commit
201fe67e81
@@ -2,27 +2,18 @@
|
|||||||
"DisabledTests":
|
"DisabledTests":
|
||||||
[
|
[
|
||||||
"Unit_hipMalloc_CoherentTst",
|
"Unit_hipMalloc_CoherentTst",
|
||||||
"Unit_printf_flags",
|
|
||||||
"Unit_printf_specifier",
|
|
||||||
"Unit_hipTextureMipmapObj2D_Check",
|
"Unit_hipTextureMipmapObj2D_Check",
|
||||||
"Unit_hipGraphAddHostNode_ClonedGraphwithHostNode",
|
"Unit_hipGraphAddHostNode_ClonedGraphwithHostNode",
|
||||||
"Unit_hipEventIpc",
|
"Unit_hipEventIpc",
|
||||||
"Unit_hipMalloc3D_Negative",
|
"Unit_hipMalloc3D_Negative",
|
||||||
"Unit_hipPointerGetAttribute_MappedMem",
|
|
||||||
"Unit_hipStreamValue_Write",
|
"Unit_hipStreamValue_Write",
|
||||||
"Unit_hipMemPoolApi_Basic",
|
|
||||||
"Unit_hipMemPoolApi_BasicAlloc",
|
"Unit_hipMemPoolApi_BasicAlloc",
|
||||||
"Unit_hipMemPoolApi_BasicTrim",
|
"Unit_hipMemPoolApi_BasicTrim",
|
||||||
"Unit_hipMemPoolApi_BasicReuse",
|
"Unit_hipMemPoolApi_BasicReuse",
|
||||||
"Unit_hipMemPoolApi_Opportunistic",
|
"Unit_hipMemPoolApi_Opportunistic",
|
||||||
"Unit_hipMemPoolApi_Default",
|
|
||||||
"Unit_hipDeviceGetUuid",
|
|
||||||
"Unit_hipGraphMemcpyNodeSetParams_Functional",
|
"Unit_hipGraphMemcpyNodeSetParams_Functional",
|
||||||
"Unit_hipMalloc3D_ValidatePitch",
|
"Unit_hipMalloc3D_ValidatePitch",
|
||||||
"Unit_hipArrayCreate_happy",
|
"Unit_hipArrayCreate_happy",
|
||||||
"Unit_hipHostRegister_Negative - int",
|
|
||||||
"Unit_hipHostRegister_Negative - float",
|
|
||||||
"Unit_hipHostRegister_Negative - double",
|
|
||||||
"Unit_hipMemAllocPitch_ValidatePitch",
|
"Unit_hipMemAllocPitch_ValidatePitch",
|
||||||
"Unit_hipArrayCreate_happy - int",
|
"Unit_hipArrayCreate_happy - int",
|
||||||
"Unit_hipArrayCreate_happy - int4",
|
"Unit_hipArrayCreate_happy - int4",
|
||||||
@@ -32,7 +23,6 @@
|
|||||||
"Unit_hipArrayCreate_happy - float",
|
"Unit_hipArrayCreate_happy - float",
|
||||||
"Unit_hipArrayCreate_happy - float2",
|
"Unit_hipArrayCreate_happy - float2",
|
||||||
"Unit_hipArrayCreate_happy - float4",
|
"Unit_hipArrayCreate_happy - float4",
|
||||||
"Unit_hipMemVmm_Basic",
|
|
||||||
"Unit_hipGraphExecMemcpyNodeSetParamsToSymbol_Functional",
|
"Unit_hipGraphExecMemcpyNodeSetParamsToSymbol_Functional",
|
||||||
"Unit_hipMallocManaged_MultiChunkMultiDevice",
|
"Unit_hipMallocManaged_MultiChunkMultiDevice",
|
||||||
"Unit_hipMallocManaged_TwoPointers - int",
|
"Unit_hipMallocManaged_TwoPointers - int",
|
||||||
@@ -43,9 +33,10 @@
|
|||||||
"Unit_hipMallocManaged_DeviceContextChange - float",
|
"Unit_hipMallocManaged_DeviceContextChange - float",
|
||||||
"Unit_hipMallocManaged_DeviceContextChange - double",
|
"Unit_hipMallocManaged_DeviceContextChange - double",
|
||||||
"Unit_hipGraphNodeGetDependentNodes_Functional",
|
"Unit_hipGraphNodeGetDependentNodes_Functional",
|
||||||
"Unit_hipGraphNodeGetDependentNodes_ParamValidation",
|
|
||||||
"Unit_hipGraphNodeGetDependencies_Functional",
|
"Unit_hipGraphNodeGetDependencies_Functional",
|
||||||
"Unit_hipGraphNodeGetDependencies_ParamValidation",
|
"Unit_hipMemGetInfo_Negative",
|
||||||
|
"Unit_hipStreamCreateWithPriority_ValidateWithEvents",
|
||||||
|
"Unit_hipStreamPerThread_StrmWaitEvt",
|
||||||
"Unit_hipMemGetInfo_DifferentMallocSmall",
|
"Unit_hipMemGetInfo_DifferentMallocSmall",
|
||||||
"Unit_hipMemGetInfo_MallocArray - int",
|
"Unit_hipMemGetInfo_MallocArray - int",
|
||||||
"Unit_hipMemGetInfo_MallocArray - int4",
|
"Unit_hipMemGetInfo_MallocArray - int4",
|
||||||
|
|||||||
@@ -216,7 +216,7 @@ TEMPLATE_TEST_CASE("Unit_hipHostRegister_Negative", "", int, float, double) {
|
|||||||
REQUIRE(devMemAvail > 0);
|
REQUIRE(devMemAvail > 0);
|
||||||
REQUIRE(hostMemFree > 0);
|
REQUIRE(hostMemFree > 0);
|
||||||
|
|
||||||
size_t memFree = (std::min)(devMemFree, hostMemFree); // which is the limiter cpu or gpu
|
size_t memFree = (std::max)(devMemFree, hostMemFree); // which is the limiter cpu or gpu
|
||||||
|
|
||||||
SECTION("hipHostRegister Negative Test - invalid memory size") {
|
SECTION("hipHostRegister Negative Test - invalid memory size") {
|
||||||
HIP_CHECK_ERROR(hipHostRegister(hostPtr, memFree, 0), hipErrorInvalidValue);
|
HIP_CHECK_ERROR(hipHostRegister(hostPtr, memFree, 0), hipErrorInvalidValue);
|
||||||
|
|||||||
@@ -162,7 +162,7 @@ TEST_CASE("Unit_hipMemPoolApi_BasicAlloc") {
|
|||||||
std::uint64_t res_after_sync = 0;
|
std::uint64_t res_after_sync = 0;
|
||||||
HIP_CHECK(hipMemPoolGetAttribute(mem_pool, attr, &res_after_sync));
|
HIP_CHECK(hipMemPoolGetAttribute(mem_pool, attr, &res_after_sync));
|
||||||
// Sync must releaae memory to OS
|
// Sync must releaae memory to OS
|
||||||
REQUIRE(res_after_sync < res_before_sync);
|
REQUIRE(res_after_sync <= res_before_sync);
|
||||||
|
|
||||||
int value = 0;
|
int value = 0;
|
||||||
attr = hipMemPoolReuseFollowEventDependencies;
|
attr = hipMemPoolReuseFollowEventDependencies;
|
||||||
@@ -189,7 +189,7 @@ TEST_CASE("Unit_hipMemPoolApi_BasicAlloc") {
|
|||||||
attr = hipMemPoolAttrReservedMemHigh;
|
attr = hipMemPoolAttrReservedMemHigh;
|
||||||
HIP_CHECK(hipMemPoolGetAttribute(mem_pool, attr, &value64));
|
HIP_CHECK(hipMemPoolGetAttribute(mem_pool, attr, &value64));
|
||||||
// Must be bigger than current
|
// Must be bigger than current
|
||||||
REQUIRE(value64 > res_after_sync);
|
REQUIRE(value64 >= res_after_sync);
|
||||||
|
|
||||||
attr = hipMemPoolAttrUsedMemCurrent;
|
attr = hipMemPoolAttrUsedMemCurrent;
|
||||||
HIP_CHECK(hipMemPoolGetAttribute(mem_pool, attr, &value64));
|
HIP_CHECK(hipMemPoolGetAttribute(mem_pool, attr, &value64));
|
||||||
|
|||||||
@@ -248,7 +248,8 @@ TEST_CASE("Unit_hipPointerGetAttribute_MappedMem") {
|
|||||||
}
|
}
|
||||||
HIP_CHECK(hipMemcpy(A_d, A_h, Nbytes, hipMemcpyHostToDevice));
|
HIP_CHECK(hipMemcpy(A_d, A_h, Nbytes, hipMemcpyHostToDevice));
|
||||||
int *ptr1 = 0, *ptr2 = 0;
|
int *ptr1 = 0, *ptr2 = 0;
|
||||||
unsigned int hostMalloc_mapped, mallocManaged;
|
unsigned int hostMalloc_mapped = 0;
|
||||||
|
unsigned int mallocManaged = 0;
|
||||||
HIP_CHECK(hipHostMalloc(&ptr1, Nbytes, hipHostMallocMapped));
|
HIP_CHECK(hipHostMalloc(&ptr1, Nbytes, hipHostMallocMapped));
|
||||||
HIP_CHECK(hipMallocManaged(&ptr2, Nbytes, hipMemAttachGlobal));
|
HIP_CHECK(hipMallocManaged(&ptr2, Nbytes, hipMemAttachGlobal));
|
||||||
HIP_CHECK(hipPointerGetAttribute(&hostMalloc_mapped,
|
HIP_CHECK(hipPointerGetAttribute(&hostMalloc_mapped,
|
||||||
|
|||||||
@@ -242,10 +242,6 @@ TEMPLATE_TEST_CASE("Unit_hipStreamValue_Write", "", (TestParams<uint32_t, PtrTyp
|
|||||||
(TestParams<uint64_t, PtrType::HostPtr>),
|
(TestParams<uint64_t, PtrType::HostPtr>),
|
||||||
(TestParams<uint64_t, PtrType::DevicePtr>),
|
(TestParams<uint64_t, PtrType::DevicePtr>),
|
||||||
(TestParams<uint64_t, PtrType::DevicePtrToHost>)) {
|
(TestParams<uint64_t, PtrType::DevicePtrToHost>)) {
|
||||||
#endif
|
|
||||||
#if HT_AMD
|
|
||||||
HipTest::HIP_SKIP_TEST("EXSWCPHIPT-126");
|
|
||||||
return;
|
|
||||||
#endif
|
#endif
|
||||||
if (!streamWaitValueSupported()) {
|
if (!streamWaitValueSupported()) {
|
||||||
HipTest::HIP_SKIP_TEST("hipStreamWaitValue not supported on this device.");
|
HipTest::HIP_SKIP_TEST("hipStreamWaitValue not supported on this device.");
|
||||||
@@ -303,11 +299,6 @@ void testWait(TEST_WAIT<typename TestType::UIntType> tc) {
|
|||||||
HipTest::HIP_SKIP_TEST("hipStreamWaitValue not supported on this device.");
|
HipTest::HIP_SKIP_TEST("hipStreamWaitValue not supported on this device.");
|
||||||
return;
|
return;
|
||||||
}
|
}
|
||||||
#if HT_AMD
|
|
||||||
HipTest::HIP_SKIP_TEST("EXSWCPHIPT-128");
|
|
||||||
return;
|
|
||||||
#endif
|
|
||||||
|
|
||||||
using UIntT = typename TestType::UIntType;
|
using UIntT = typename TestType::UIntType;
|
||||||
constexpr auto ptrType = TestType::ptrType;
|
constexpr auto ptrType = TestType::ptrType;
|
||||||
constexpr UIntT defaultMask = ~static_cast<UIntT>(0);
|
constexpr UIntT defaultMask = ~static_cast<UIntT>(0);
|
||||||
@@ -478,10 +469,6 @@ DEFINE_STREAM_WAIT_VAL_TEST_CASES_INT64("NoMask_Nor",
|
|||||||
|
|
||||||
// Negative Tests
|
// Negative Tests
|
||||||
TEST_CASE("Unit_hipStreamValue_Negative_InvalidMemory") {
|
TEST_CASE("Unit_hipStreamValue_Negative_InvalidMemory") {
|
||||||
#if HT_AMD
|
|
||||||
HipTest::HIP_SKIP_TEST("EXSWCPHIPT-96");
|
|
||||||
return;
|
|
||||||
#endif
|
|
||||||
if (!streamWaitValueSupported()) {
|
if (!streamWaitValueSupported()) {
|
||||||
HipTest::HIP_SKIP_TEST("hipStreamWaitValue not supported on this device.");
|
HipTest::HIP_SKIP_TEST("hipStreamWaitValue not supported on this device.");
|
||||||
return;
|
return;
|
||||||
@@ -513,10 +500,6 @@ TEST_CASE("Unit_hipStreamValue_Negative_InvalidMemory") {
|
|||||||
}
|
}
|
||||||
|
|
||||||
TEMPLATE_TEST_CASE("Unit_hipStreamWaitValue_Negative_InvalidFlag", "", uint32_t, uint64_t) {
|
TEMPLATE_TEST_CASE("Unit_hipStreamWaitValue_Negative_InvalidFlag", "", uint32_t, uint64_t) {
|
||||||
#if HT_AMD
|
|
||||||
HipTest::HIP_SKIP_TEST("EXSWCPHIPT-96");
|
|
||||||
return;
|
|
||||||
#endif
|
|
||||||
if (!streamWaitValueSupported()) {
|
if (!streamWaitValueSupported()) {
|
||||||
HipTest::HIP_SKIP_TEST("hipStreamWaitValue not supported on this device.");
|
HipTest::HIP_SKIP_TEST("hipStreamWaitValue not supported on this device.");
|
||||||
return;
|
return;
|
||||||
|
|||||||
Referencia en una nueva incidencia
Block a user